<?php
/**
 * Plugin template functions.
 * 
 * @since 1.2.0
 * 
 * @package    Nav Menu Collapse
 * @subpackage Template Functions
 */

if (!defined('ABSPATH')) exit;

if (!function_exists('nmc_is_ajax_action'))
{
	/**
	 * Check to see if an AJAX action is being executed.
	 * 
	 * @since 1.2.0
	 * 
	 * @param  string  $action Action to check for.
	 * @return boolean         True if the action is being executed.
	 */
	function nmc_is_ajax_action($action)
	{
		if (!NMC_AJAX) return false;

		$current_action = (isset($_GET['action'])) ? $_GET['action'] : '';
		$current_action = (empty($current_action) && isset($_POST['action'])) ? $_POST['action'] : $current_action;

		return ($action == $current_action);
	}
}

if (!function_exists('nmc_is_plugin_active'))
{
	/**
	 * Check to see if a plugin is active.
	 * 
	 * @since 1.2.0
	 * 
	 * @param  string  $path Path for the plugin to check.
	 * @return boolean       True if the plugin is active.
	 */
	function nmc_is_plugin_active($path)
	{
		if (!function_exists('is_plugin_active'))
		{
			require_once(ABSPATH . 'wp-admin/includes/plugin.php');
		}

		return is_plugin_active($path);
	}
}

if (!function_exists('nmc_remove_spacing'))
{
	/**
	 * Remove line breaks and tabs from a string.
	 * 
	 * @since 1.2.0
	 * 
	 * @param  string $html Raw HTML to remove spacing from.
	 * @return string       HTML with spacing removed.
	 */
	function nmc_remove_spacing($html)
	{
		return str_replace(array(PHP_EOL, "\r", "\n", "\t"), '', $html);
	}
}
